@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2010-2015  Tetsuo Handa <penguin-kernel@I-love.SAKURA.ne.jp>
  *
- * Version: 1.0.37   2017/09/17
+ * Version: 1.0.38   2018/04/01
  */
 
 #include "internal.h"
@@ -1422,7 +1422,7 @@ static int __init ccs_init(void)
 		goto out;
 	ccs_main_init();
 	ccs_update_security_ops(ops);
-	printk(KERN_INFO "AKARI: 1.0.37   2017/09/17\n");
+	printk(KERN_INFO "AKARI: 1.0.38   2018/04/01\n");
 	printk(KERN_INFO
 	       "Access Keeping And Regulating Instrument registered.\n");
 	return 0;
@@ -1506,7 +1506,8 @@ struct ccs_security *ccs_find_task_security(const struct task_struct *task)
 	struct list_head *list = &ccs_task_security_list
 		[hash_ptr((void *) task, CCS_TASK_SECURITY_HASH_BITS)];
 	/* Make sure INIT_LIST_HEAD() in ccs_mm_init() takes effect. */
-	while (!list->next);
+	while (!list->next)
+		smp_rmb();
 	rcu_read_lock();
 	list_for_each_entry_rcu(ptr, list, list) {
 		if (ptr->task != task)
